@@ -45,6 +45,12 @@
 #include <QImage>
 #include <QGLWidget>
 
+#if PY_MAJOR_VERSION >= 3
+#define INT_CHECK PyLong_Check
+#else
+#define INT_CHECK PyInt_Check
+#endif
+
 using namespace boost::python;
 using namespace Enki;
 
@@ -105,11 +111,11 @@ struct Vector_from_python
 			
 			PyObject* item0(PyTuple_GetItem(objPtr, 0));
 			assert (item0);
-			if (!(PyFloat_Check(item0) || PyInt_Check(item0)))
+			if (!(PyFloat_Check(item0) || INT_CHECK(item0)))
 				return 0;
 			PyObject* item1(PyTuple_GetItem(objPtr, 1));
 			assert (item1);
-			if (!(PyFloat_Check(item1) || PyInt_Check(item1)))
+			if (!(PyFloat_Check(item1) || INT_CHECK(item1)))
 				return 0;
 		}
 		else
@@ -120,11 +126,11 @@ struct Vector_from_python
 			
 			PyObject* item0(PyList_GetItem(objPtr, 0));
 			assert (item0);
-			if (!(PyFloat_Check(item0) || PyInt_Check(item0)))
+			if (!(PyFloat_Check(item0) || INT_CHECK(item0)))
 				return 0;
 			PyObject* item1(PyList_GetItem(objPtr, 1));
 			assert (item1);
-			if (!(PyFloat_Check(item1) || PyInt_Check(item1)))
+			if (!(PyFloat_Check(item1) || INT_CHECK(item1)))
 				return 0;
 		}
 		
@@ -365,14 +371,6 @@ struct PythonViewer: public ViewerWidget
 		managedObjectsAliases[&typeid(EPuckWrap)] = &typeid(EPuck);
 	}
 	
-	void sceneCompletedHook()
-	{
-		glColor3d(0,0,0);
-		renderText(10, height()-50, tr("rotate camera by moving mouse while pressing ctrl+left mouse button"));
-		renderText(10, height()-30, tr("move camera on x/y by moving mouse while pressing ctrl+shift+left mouse button"));
-		renderText(10, height()-10, tr("move camera on z by moving mouse while pressing ctrl+shift+right mouse button"));
-	}
-	
 	void timerEvent(QTimerEvent * event)
 	{
 		// get back Python lock
@@ -548,7 +546,7 @@ BOOST_PYTHON_MODULE(pyenki)
 		.def("runInViewer", runInViewer, runInViewer_overloads(args("self", "camPos", "camAltitude", "camYaw", "camPitch", "wallsHeight")))
 	;
 	
-	class_<WorldWithTexturedGround, bases<World> >("WorldWithTexturedGround",
+	class_<WorldWithTexturedGround, bases<WorldWithoutObjectsOwnership> >("WorldWithTexturedGround",
 		init<double, double, const std::string&, optional<const Color&> >(args("width", "height", "ppmFileName", "wallsColor"))
 	)
 		.def(init<double, const std::string&, optional<const Color&> >(args("r", "ppmFileName", "wallsColor")))
